@@ -10,4 +10,7 @@ class ICoordinatesList(Interface):
                             required=True,
                             missing_value=[ ],
                             value_type=schema.TextLine(title=u"Region", default=u'None'))
-    
\ No newline at end of file
+    
+    
+class MayHaveTagsWithCoordinates(Interface):
+    """ This object wants to export its titles to Type X """
